ISgeometry: Incoherent Scatter Geometry

ISgeometryR Documentation

Incoherent Scatter Geometry

Description

Incoherent scatter radar measurement geometry evaluation

Details

Estimates of incoherent integration times, assuming low SNR and Gaussian beam shpes

Following coordinates are loaded to the global workspace at the time when the package is loaded, and are available for the function calls:

Skibotn SKI = c(69.34,20.31)

Kaiseniemi KAI = c(68.27,19.45)

Karesuvanto KAR = c(68.48,22.52)

Tromso TRO = c(69.58,19.23)

Kiruna KIR = c(67.87,20.43)

Sodankyla SOD = c(67.37,26.63)

Longyearbyen ESR = c(78.15,16.03)

Andoya AND = c(69.31,16.12)

Esrange ESRA = c(67.88,21.12)

Lokkavaara LOK = c(67.81,27.69)

Muonio MUO = c(67.96,23.68)

Kilpisjarvi KIL = c(69.02,20.86)

Säytsjärvi SAY = c(69.35,27.20)

Suolojavrras SUO = c(69.57,23.57)

Miellejokk MIE = c(68.34,18.96)

Parivierra PAR = c(67.06,19.59)

Järämä JAR = c(68.38,21.08)

Kautokeino KAU = c(69.01,23.04)

Overbygd OVE = c(69.03,19.29)

Abisko ABI = c(68.37,18.75)

Sekkujärvi SKJ = c(68.11,21.00)

Järämä JRM = c(68.39,21.01)

Karasjokk KJK = c(69.46,25.53)

Alta ALT = c(69.86,22.96)

Masi MAS = c(69.44,23.65)

Altaelva AEV = c(69.19,23.57)

Hetta HTA = c(68.39,23.60)

Palojoensuu PLJ = c(68.28,23.08)

Peera PEE = c(68.88,21.06)

FUNCTIONS:

multistaticIntegrationTimes integration time evaluation

integrationTimeVsArea calculates and/or plots the covered area as function of integration time

savepdf save contents of a figure window in a pdf file

parameterErrorEstimats Standard deviations of fitted plasma parameters

Author(s)

Ilkka Virtanen (University of Oulu, Finland) ilkka.i.virtanen@oulu.fi


ilkkavir/ISgeometry documentation built on Jan. 19, 2025, 5:26 p.m.