integrationTimeVsArea: integrationTimeVsArea

View source: R/ISgeometry.R

integrationTimeVsAreaR Documentation

integrationTimeVsArea

Description

Calculates and/or plots the covered area as function of integration time

Usage

integrationTimeVsArea(A,levels=100,type='isotropic',plot=TRUE)

Arguments

A

A list given by multistaticIntegrationTimes

levels

Either a single number giving the number of integration time levels calculated, or a vector giving the integration time levels explicitly.

type

Either 'isotropic' or 'velocity'.

plot

If true, a graph is drawn. If false, only data is returned.

Value

A list containing the integration times (levels) in seconds and areas in square kilometers (areas). If plot=T and no return variable is given, nothing is returned.

Author(s)

Mikko Orispaa mikko.orispaa@oulu.fi

Examples

  
  ## First calculate some integration times.
  ## Note the return variable A.
  A <- multistaticIntegrationTimes(fradar=235e6,Pt=2e6)
  
  ## Plot the integration times vs areas
  integrationTimeVsArea(A,type='isotropic')
  integrationTimeVsArea(A,levels = seq(1,100,by=5), type='velocity')
  
  ## Do not plot, only calculate
  B <- integrationTimeVsArea(A,type='isotropic',plot=F)
  
  

ilkkavir/ISgeometry documentation built on Jan. 19, 2025, 5:26 p.m.